@@ -5,6 +5,7 @@ use crate::api_params::AnswerCallbackQueryParams;
 use crate::api_params::AnswerInlineQueryParams;
 use crate::api_params::AnswerPreCheckoutQueryParams;
 use crate::api_params::AnswerShippingQueryParams;
+use crate::api_params::AnswerWebAppQueryParams;
 use crate::api_params::ApproveChatJoinRequestParams;
 use crate::api_params::BanChatMemberParams;
 use crate::api_params::BanChatSenderChatParams;
@@ -30,10 +31,12 @@ use crate::api_params::ForwardMessageParams;
 use crate::api_params::GetChatAdministratorsParams;
 use crate::api_params::GetChatMemberCountParams;
 use crate::api_params::GetChatMemberParams;
+use crate::api_params::GetChatMenuButtonParams;
 use crate::api_params::GetChatParams;
 use crate::api_params::GetFileParams;
 use crate::api_params::GetGameHighScoresParams;
 use crate::api_params::GetMyCommandsParams;
+use crate::api_params::GetMyDefaultAdministratorRightsParams;
 use crate::api_params::GetStickerSetParams;
 use crate::api_params::GetUpdatesParams;
 use crate::api_params::GetUserProfilePhotosParams;
@@ -64,12 +67,14 @@ use crate::api_params::SendVideoParams;
 use crate::api_params::SendVoiceParams;
 use crate::api_params::SetChatAdministratorCustomTitleParams;
 use crate::api_params::SetChatDescriptionParams;
+use crate::api_params::SetChatMenuButtonParams;
 use crate::api_params::SetChatPermissionsParams;
 use crate::api_params::SetChatPhotoParams;
 use crate::api_params::SetChatStickerSetParams;
 use crate::api_params::SetChatTitleParams;
 use crate::api_params::SetGameScoreParams;
 use crate::api_params::SetMyCommandsParams;
+use crate::api_params::SetMyDefaultAdministratorRightsParams;
 use crate::api_params::SetStickerPositionInSetParams;
 use crate::api_params::SetStickerSetThumbParams;
 use crate::api_params::SetWebhookParams;
@@ -81,13 +86,16 @@ use crate::api_params::UnpinChatMessageParams;
 use crate::api_params::UploadStickerFileParams;
 use crate::objects::BotCommand;
 use crate::objects::Chat;
+use crate::objects::ChatAdministratorRights;
 use crate::objects::ChatInviteLink;
 use crate::objects::ChatMember;
 use crate::objects::File as FileObject;
 use crate::objects::GameHighScore;
+use crate::objects::MenuButton;
 use crate::objects::Message;
 use crate::objects::MessageId;
 use crate::objects::Poll;
+use crate::objects::SentWebAppMessage;
 use crate::objects::StickerSet;
 use crate::objects::Update;
 use crate::objects::User;
@@ -940,6 +948,41 @@ pub trait TelegramApi {
         self.request("getGameHighScores", Some(params))
     }
 
+    fn set_my_default_administrator_rights(
+        &self,
+        params: &SetMyDefaultAdministratorRightsParams,
+    ) -> Result<MethodResponse<bool>, Self::Error> {
+        self.request("setMyDefaultAdministratorRights", Some(params))
+    }
+
+    fn get_my_default_administrator_rights(
+        &self,
+        params: &GetMyDefaultAdministratorRightsParams,
+    ) -> Result<MethodResponse<ChatAdministratorRights>, Self::Error> {
+        self.request("getMyDefaultAdministratorRights", Some(params))
+    }
+
+    fn answer_web_app_query(
+        &self,
+        params: &AnswerWebAppQueryParams,
+    ) -> Result<MethodResponse<SentWebAppMessage>, Self::Error> {
+        self.request("answerWebAppQuery", Some(params))
+    }
+
+    fn set_chat_menu_button(
+        &self,
+        params: SetChatMenuButtonParams,
+    ) -> Result<MethodResponse<bool>, Self::Error> {
+        self.request("setChatMenuButton", Some(params))
+    }
+
+    fn get_chat_menu_button(
+        &self,
+        params: GetChatMenuButtonParams,
+    ) -> Result<MethodResponse<MenuButton>, Self::Error> {
+        self.request("getChatMenuButton", Some(params))
+    }
+
     fn request_without_body<T: serde::de::DeserializeOwned>(
         &self,
         method: &str,
